@@ -2,4 +2,8 @@
 Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
+
+__all__ = ["Conditions"]
+
+from cfnlint.conditions._errors import UnknownSatisfisfaction
 from cfnlint.conditions.conditions import Conditions
